@@ -8,6 +8,8 @@ import redis
 import schedule
 import time
 
+from rosetta_dispatcher.redis_client import RedisClient
+
 
 class HeartbeatReporter:
     def __init__(self,
@@ -17,6 +19,7 @@ class HeartbeatReporter:
                  host_name: str,
                  redis_host: str,
                  redis_port: str,
+                 password: str = None,
                  interval: int = 60):
         self.host_ip = host_ip
         self.host_name = host_name
@@ -26,7 +29,7 @@ class HeartbeatReporter:
         self.interval = interval
         self.namespace = namespace
         self.service_name = service_name
-        self.pool = redis.ConnectionPool(host=redis_host, port=redis_port, decode_responses=True)
+        self.client = RedisClient(host=redis_host, port=redis_port, password=password, decode_responses=True)
 
         schedule.every(self.interval).seconds.do(self.send_report)
 
@@ -40,7 +43,7 @@ class HeartbeatReporter:
 
     def send_report(self):
         if self.running:
-            r = redis.Redis(connection_pool=self.pool)
+            r = self.client.conn
 
             data = {
                 "service_name": self.service_name,
