@@ -7,14 +7,17 @@ import redis
 from rosetta_dispatcher.idtool import idtool
 from rosetta_dispatcher.model.dispatch_request_model import DispatchRequestModel
 from rosetta_dispatcher.model.dispatch_response_model import DispatchResponseModel
+from rosetta_dispatcher.redis_client import RedisClient
 
 
 class DispatchServer:
-    def __init__(self, redis_host: str, redis_port: int, response_timeout: int = 60):
+    def __init__(self, redis_host: str, redis_port: int, response_timeout: int = 60, password=None):
         self.redis_host = redis_host
         self.redis_port = redis_port
+        self.password = password
         self.response_timeout = response_timeout
-        self.pool = redis.ConnectionPool(host=redis_host, port=redis_port, decode_responses=True)
+        self.client = RedisClient(host=redis_host, port=redis_port, password=self.password, decode_responses=True)
+
 
     def preprocess_request(self, strrequest: str) -> DispatchRequestModel:
         if strrequest:
@@ -48,12 +51,12 @@ class DispatchServer:
         return result
 
     def fetch(self, service_queue: str, batch_count=16, timeout: int = 10) -> List[DispatchRequestModel]:
-        r = redis.Redis(connection_pool=self.pool)
-        batch_requests = self.__batch_fetch__(r, service_queue, batch_count)
-        if batch_requests:
-            return batch_requests
+        r = self.client.conn
+        result = self.__batch_fetch__(r, service_queue, batch_count)
+
+        if result:
+            return result
 
-        result = []
         # block and wait data.
         trequest = r.blpop(keys=service_queue, timeout=timeout)
         # None data fetched.
@@ -67,11 +70,10 @@ class DispatchServer:
         batch_requests = self.__batch_fetch__(r, service_queue, batch_count-1)
         if batch_requests:
             result += batch_requests
-
         return result
 
     def send_response(self, response_queue: str, response: DispatchResponseModel):
-        r = redis.Redis(connection_pool=self.pool)
+        r = self.client.conn
         data = response.dict(exclude_none=True)
         r.rpush(response_queue, json.dumps(data, ensure_ascii=True))
         r.expire(response_queue, time=self.response_timeout)
@@ -80,7 +82,7 @@ class DispatchServer:
         if len(response_queue_list) != len(response_queue_list):
             raise Exception("response queue list is not equal response_list")
 
-        r = redis.Redis(connection_pool=self.pool)
+        r = self.client.conn
         p = r.pipeline()
         for request, response in zip(response_queue_list, response_list):
             data = response.dict(exclude_none=True)
