@@ -3,8 +3,12 @@ from datetime import datetime
 
 from rosetta_dispatcher.dispatch_client import DispatchClient
 
-host = '61.160.36.168'
-port = 4032
+host = '10.130.64.136'
+port = 4012
+
+# host = '123.57.176.234'
+# port = 6379
+
 
 dc = DispatchClient(redis_host=host, redis_port=port)
 
@@ -20,7 +24,7 @@ data = {
 }
 while True:
     start = datetime.utcnow()
-    result = dc.process(service_queue='NMT_RPC_QUEUE_DEV', data=json.dumps(data), timeout=10)
+    result = dc.process(service_queue='BATCH_WORKER_QUEUE_DEV', data=json.dumps(data), timeout=10)
     end = datetime.utcnow()
     print(end-start)
     print(result)
